@@ -100,41 +100,27 @@ cleanup:
  * @param branch_name Name for the branch
  * @param commit Commit to which branch should point.
  * @param force Overwrite existing branch
- * @param signature The identity that will be used to populate the reflog entry
- * @param message The one line long message to the reflog. If NULL, default is
- *        "Branch: created"
  * @return S4 class git_branch
  */
 SEXP git2r_branch_create(
     SEXP branch_name,
     SEXP commit,
-    SEXP force,
-    SEXP signature,
-    SEXP message)
+    SEXP force)
 {
     SEXP repo;
     SEXP result = R_NilValue;
     int err;
     int overwrite = 0;
-    const char *log = NULL;
     git_commit *target = NULL;
-    git_signature *who = NULL;
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_string(branch_name))
+    if (git2r_arg_check_string(branch_name))
         git2r_error(git2r_err_string_arg, __func__, "branch_name");
-    if (GIT_OK != git2r_arg_check_commit(commit))
+    if (git2r_arg_check_commit(commit))
         git2r_error(git2r_err_commit_arg, __func__, "commit");
-    if (GIT_OK != git2r_arg_check_logical(force))
+    if (git2r_arg_check_logical(force))
         git2r_error(git2r_err_logical_arg, __func__, "force");
-    if (GIT_OK != git2r_arg_check_signature(signature))
-        git2r_error(git2r_err_signature_arg, __func__, "signature");
-    if (R_NilValue != message) {
-        if (GIT_OK != git2r_arg_check_string(message))
-            git2r_error(git2r_err_string_arg, __func__, "message");
-        log = CHAR(STRING_ELT(message, 0));
-    }
 
     repo = GET_SLOT(commit, Rf_install("repo"));
     repository = git2r_repository_open(repo);
@@ -148,18 +134,12 @@ SEXP git2r_branch_create(
     if (LOGICAL(force)[0])
         overwrite = 1;
 
-    err = git2r_signature_from_arg(&who, signature);
-    if (GIT_OK != err)
-        goto cleanup;
-
     err = git_branch_create(
         &reference,
         repository,
         CHAR(STRING_ELT(branch_name, 0)),
         target,
-        overwrite,
-        who,
-        log);
+        overwrite);
     if (GIT_OK != err)
         goto cleanup;
 
@@ -173,9 +153,6 @@ cleanup:
     if (target)
         git_commit_free(target);
 
-    if (who)
-        git_signature_free(who);
-
     if (repository)
         git_repository_free(repository);
 
@@ -202,7 +179,7 @@ SEXP git2r_branch_delete(SEXP branch)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     repository = git2r_repository_open(GET_SLOT(branch, Rf_install("repo")));
@@ -244,7 +221,7 @@ SEXP git2r_branch_is_head(SEXP branch)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     repository = git2r_repository_open(GET_SLOT(branch, Rf_install("repo")));
@@ -301,7 +278,7 @@ SEXP git2r_branch_list(SEXP repo, SEXP flags)
     git_reference *reference = NULL;
     git_branch_t type;
 
-    if (GIT_OK != git2r_arg_check_integer(flags))
+    if (git2r_arg_check_integer(flags))
         git2r_error(git2r_err_integer_arg, __func__, "flags");
 
     repository = git2r_repository_open(repo);
@@ -371,7 +348,7 @@ SEXP git2r_branch_canonical_name(SEXP branch)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     repository = git2r_repository_open(GET_SLOT(branch, Rf_install("repo")));
@@ -421,7 +398,7 @@ SEXP git2r_branch_upstream_canonical_name(SEXP branch)
     git_config *cfg = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     type = INTEGER(GET_SLOT(branch, Rf_install("type")))[0];
@@ -433,7 +410,7 @@ SEXP git2r_branch_upstream_canonical_name(SEXP branch)
     if (!repository)
         git2r_error(git2r_err_invalid_repository, __func__, NULL);
 
-    err = git_repository_config(&cfg, repository);
+    err = git_repository_config_snapshot(&cfg, repository);
     if (GIT_OK != err)
         goto cleanup;
 
@@ -483,7 +460,7 @@ SEXP git2r_branch_remote_name(SEXP branch)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     type = INTEGER(GET_SLOT(branch, Rf_install("type")))[0];
@@ -542,7 +519,7 @@ SEXP git2r_branch_remote_url(SEXP branch)
     git_remote *remote = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     type = INTEGER(GET_SLOT(branch, Rf_install("type")))[0];
@@ -602,43 +579,29 @@ cleanup:
  * @param branch Branch to rename
  * @param new_branch_name The new name for the branch
  * @param force Overwrite existing branch
- * @param signature The identity that will be used to populate the reflog entry
- * @param message The one line long message to the reflog. If NULL, the default
- *        value is appended
  * @return The renamed S4 class git_branch
  */
 SEXP git2r_branch_rename(
     SEXP branch,
     SEXP new_branch_name,
-    SEXP force,
-    SEXP signature,
-    SEXP message)
+    SEXP force)
 {
     SEXP repo;
     SEXP result = R_NilValue;
     int err;
     int overwrite = 0;
-    const char *log = NULL;
     const char *name = NULL;
     git_branch_t type;
-    git_signature *who = NULL;
     git_reference *reference = NULL;
     git_reference *new_reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
-    if (GIT_OK != git2r_arg_check_string(new_branch_name))
+    if (git2r_arg_check_string(new_branch_name))
         git2r_error(git2r_err_string_arg, __func__, "new_branch_name");
-    if (GIT_OK != git2r_arg_check_logical(force))
+    if (git2r_arg_check_logical(force))
         git2r_error(git2r_err_logical_arg, __func__, "force");
-    if (GIT_OK != git2r_arg_check_signature(signature))
-        git2r_error(git2r_err_signature_arg, __func__, "signature");
-    if (R_NilValue != message) {
-        if (GIT_OK != git2r_arg_check_string(message))
-            git2r_error(git2r_err_string_arg, __func__, "message");
-        log = CHAR(STRING_ELT(message, 0));
-    }
 
     repo = GET_SLOT(branch, Rf_install("repo"));
     repository = git2r_repository_open(repo);
@@ -654,17 +617,11 @@ SEXP git2r_branch_rename(
     if (LOGICAL(force)[0])
         overwrite = 1;
 
-    err = git2r_signature_from_arg(&who, signature);
-    if (GIT_OK != err)
-        goto cleanup;
-
     err = git_branch_move(
         &new_reference,
         reference,
         CHAR(STRING_ELT(new_branch_name, 0)),
-        overwrite,
-        who,
-        log);
+        overwrite);
     if (GIT_OK != err)
         goto cleanup;
 
@@ -678,9 +635,6 @@ cleanup:
     if (new_reference)
         git_reference_free(new_reference);
 
-    if (who)
-        git_signature_free(who);
-
     if (repository)
         git_repository_free(repository);
 
@@ -709,7 +663,7 @@ SEXP git2r_branch_target(SEXP branch)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     repository = git2r_repository_open(GET_SLOT(branch, Rf_install("repo")));
@@ -764,7 +718,7 @@ SEXP git2r_branch_get_upstream(SEXP branch)
     git_reference *upstream = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
 
     repo = GET_SLOT(branch, Rf_install("repo"));
@@ -826,10 +780,10 @@ SEXP git2r_branch_set_upstream(SEXP branch, SEXP upstream_name)
     git_reference *reference = NULL;
     git_repository *repository = NULL;
 
-    if (GIT_OK != git2r_arg_check_branch(branch))
+    if (git2r_arg_check_branch(branch))
         git2r_error(git2r_err_branch_arg, __func__, "branch");
     if (R_NilValue != upstream_name) {
-        if (GIT_OK != git2r_arg_check_string(upstream_name))
+        if (git2r_arg_check_string(upstream_name))
             git2r_error(git2r_err_string_arg, __func__, "upstream_name");
         u_name = CHAR(STRING_ELT(upstream_name, 0));
     }
