@@ -22,6 +22,11 @@
 #include <R.h>
 #include <Rinternals.h>
 
-SEXP git2r_clone(SEXP url, SEXP local_path, SEXP credentials, SEXP progress);
+SEXP git2r_clone(
+    SEXP url,
+    SEXP local_path,
+    SEXP bare,
+    SEXP credentials,
+    SEXP progress);
 
 #endif
