@@ -22,7 +22,7 @@ dir.create(path)
 
 ## Initialize a repository
 repo <- init(path)
-config(repo, user.name="Developer", user.email="developer@example.org")
+config(repo, user.name="Alice", user.email="alice@example.org")
 
 ## Create a file, add and commit
 writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
@@ -107,14 +107,15 @@ stopifnot(identical(m_3@conflicts, TRUE))
 stopifnot(identical(m_3@sha, character(0)))
 
 ## Check status; Expect to have one unstaged unmerged conflict.
-stopifnot(identical(status(repo, verbose = FALSE),
+stopifnot(identical(status(repo),
                     structure(list(staged = structure(list(),
                                        .Names = character(0)),
                                    unstaged = structure(list(unmerged = "test.txt"),
                                        .Names = "unmerged"),
                                    untracked = structure(list(),
                                        .Names = character(0))),
-                              .Names = c("staged", "unstaged", "untracked"))))
+                              .Names = c("staged", "unstaged", "untracked"),
+                              class = "git_status")))
 
 ## Cleanup
 unlink(path, recursive=TRUE)
